@@ -22,6 +22,8 @@ Date: 05/31/2023
 Version: 0.1.2
 """
 import os
+from .list_utils import make_list
+from .type_utils import get_alpha_ints
 def quoteIt(st: str, ls: list) -> str:
     """
     Quotes specific elements in a string.
@@ -110,6 +112,42 @@ def eatAll(string: str, list_objects:(str or list)) -> any:
     if string and list_objects:
         string = eatOuter(string, list_objects)
     return string
+
+
+
+def eatElse(
+    stringObj,
+    chars=None,
+    ints=True,
+    alpha=True,
+    lower=True,
+    capitalize=True,
+    string=True,
+    listObj=True
+):
+    alpha_ints = get_alpha_ints(
+        ints=True,
+        alpha=True,
+        lower=True,
+        capitalize=True,
+        string=True,
+        listObj=True
+        )
+    chars = make_list(chars or [])+alpha_ints
+
+    while True:
+        if stringObj:
+            str_0 = stringObj[0] not in chars
+            str_1 = stringObj[-1] not in chars
+            str_eat = str_0 or str_1
+            if not str_eat:
+                return stringObj
+            if stringObj and str_0:
+                stringObj = stringObj[1:] if len(stringObj) !=1 else ""
+            if stringObj and str_1:
+                stringObj = stringObj[:-1] if len(stringObj) !=1 else ""   
+        else:
+            return stringObj
 def safe_split(obj, ls):
     """
     Safely splits a string using multiple delimiters.
@@ -185,6 +223,7 @@ def url_join(*paths):
             final_path = f"{final_path}/{path}"
     return final_path
        
-    
+def clean_line(line):
+    return eatAll(line,[' ','','\t','\n'])
 def capitalize(string):
     return string[:1].upper() + string[1:].lower() if string else string
